package com.app.resiliency;

import com.amazonaws.services.ec2.AmazonEC2;
import com.amazonaws.services.ec2.AmazonEC2ClientBuilder;
import com.amazonaws.services.ec2.model.DescribeInstancesResult;
import com.amazonaws.services.ec2.model.DescribeInstancesRequest;
import com.amazonaws.services.ec2.model.Filter;
import com.amazonaws.services.ec2.model.TerminateInstancesRequest;

import java.util.Collections;

public class InstanceFailover {

    private static final AmazonEC2 EC2_CLIENT = AmazonEC2ClientBuilder.defaultClient();
    private String vpcId;

    InstanceFailover(String vpcId) {
        this.vpcId = vpcId;
    }

    public void failover() {
        try {
            DescribeInstancesResult describeInstancesResult
                    = EC2_CLIENT.describeInstances(new DescribeInstancesRequest().withFilters(
                    new Filter("vpc-id", Collections.singletonList(vpcId)),
                    new Filter("instance-state-name", Collections.singletonList("running"))));
            String instanceId = describeInstancesResult.getReservations().get(0).getInstances().get(0).getInstanceId();
            System.out.println("Terminating instanceId " + instanceId);

            TerminateInstancesRequest terminateInstancesRequest = new TerminateInstancesRequest();
            terminateInstancesRequest.setInstanceIds(Collections.singletonList(instanceId));
            EC2_CLIENT.terminateInstances(terminateInstancesRequest);
        } catch (Exception exception) {
            System.out.println("Unkown exception occured " + exception.getMessage());
        }
    }

}